@@ -1,3 +1,4 @@
+import abc
 import logging
 import datetime
 import json
@@ -10,12 +11,13 @@ class DateTimeEncoder(json.JSONEncoder):
             return obj.isoformat()
 
 
-class GenericMetricsProducer:
+class GenericMetricsProducer(abc.ABC):
     def __init__(self, config):
         self.config = config
         self.logger = logging.getLogger(self.__class__.__name__)
         self.logger.info(f"Creating {self.__class__.__name__}")
 
+    @abc.abstractmethod
     def send_metrics(self, metrics):
         """Write metrics into a data store or other metrics system.
 
